#
# spec file for package kphotoalbum
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without released
Name:           kphotoalbum
Version:        5.12.0
Release:        1.2
Summary:        A photo administration utility
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Viewers
URL:            https://www.kphotoalbum.org/
Source:         https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz.sig
Source2:        kphotoalbum.keyring
%endif
BuildRequires:  QtAV-devel
BuildRequires:  cmake >= 3.18.0
BuildRequires:  extra-cmake-modules > 5.92
BuildRequires:  fdupes
BuildRequires:  libexiv2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  cmake(KF5Archive)
BuildRequires:  cmake(KF5Completion)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5CoreAddons) >= 5.78.0
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5JobWidgets)
BuildRequires:  cmake(KF5KDcraw)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Purpose)
BuildRequires:  cmake(KF5TextWidgets)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Marble)
BuildRequires:  cmake(Phonon4Qt5)
BuildRequires:  cmake(Qt5Core) >= 5.15
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libvlc)
Requires:       sqlite3
Recommends:     marble

%description
KPhotoAlbum is a tool to help describe images, and to search in the pile
of images. With KPhotoAlbum it is today possible to find any image
in less than 5 seconds, let that be an image with a special person,
an image from a special place, or even both.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name}
%{kf5_find_htmldocs}

# Fix rpmlint warning text file has executable bits
chmod 644 %{buildroot}%{_kf5_applicationsdir}/org.kde.kphotoalbum.open-raw.desktop

%fdupes %{buildroot}

%files
%license LICENSES/*
%doc CHANGELOG.md README.md
%{_kf5_applicationsdir}/*
%{_kf5_appstreamdir}/org.kde.kphotoalbum.appdata.xml
%{_kf5_bindir}/*
%{_kf5_configdir}/kphotoalbumrc
%{_kf5_htmldir}/en/kphotoalbum/
%{_kf5_iconsdir}/hicolor/*/*/*.png
%{_kf5_iconsdir}/hicolor/scalable/apps/kphotoalbum.svg
%{_kf5_libdir}/libkpabase.so
%{_kf5_libdir}/libkpaexif.so
%{_kf5_libdir}/libkpathumbnails.so
%{_kf5_sharedir}/kphotoalbum/

%files lang -f %{name}.lang

%changelog
* Mon Nov 27 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.12.0
  https://www.kphotoalbum.org/2023/11/27/anniversary-release-kphotoalbum-5.12.0/
  New features:
  * Support annotating images from the viewer by using letters
    to assign tags
  * Add option to sort category page by natural order (kde#475339)
  * Allow selecting a date range in the DateBar via keyboard
  * Allow closing the annotation dialog's fullscreen preview
    using the Escape key
- Drop patch, no longer needed:
  * kphotoalbum-exiv2.patch
* Thu Nov  9 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add kphotoalbum-exiv2.patch: Fix linking against libexiv2.so.
* Wed Jul 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.11.0
  * Fix issue where non-empty time units in the date bar were
    incorrectly greyed out (kde#467903)
  * Fix bug with the date bar showing and selecting incorrect
    date ranges (kde#468045)
  * Fix crash when the annotation dialog is opened from the
    viewer window and the viewer is closed before the
    annotation dialog (kde#470889)
  * Fix inconsistent UI where menu actions would not immediately
    be updated to reflect a change (kde#472109, kde#472113)
- Drop patches, now upstream:
  * 0001-Fixed-compilation-with-exiv2-0.28.patch
  * 0002-Less-macros-by-simply-using-auto.patch
  * 0003-Use-Exifdatum-toInt64-instead-of-toUint32.patch
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Add patches:
  * 0001-Fixed-compilation-with-exiv2-0.28.patch
  * 0002-Less-macros-by-simply-using-auto.patch
  * 0003-Use-Exifdatum-toInt64-instead-of-toUint32.patch
* Sun Apr 16 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to 5.10.0
  Changed
  * View-related actions formerly found in the "Settings" menu were
    moved to the "View" menu.
  * Make options "Display Labels in Thumbnail View" and
    "Display Categories in Thumbnail View" reachable via the "View"
    menu and allow both actions to be assigned keyboard shortcuts
  * Store the untagged tag information inside the index.xml file
    instead of the Settings
  * Change scroll direction in the annotation dialog's date edit
    fields to match common (western) expectations and the date
    picker.
  * Prevent scrolling past the occupied areas of the date bar.
  * Files are now always created with group read/write permissions
  * When exiting the demo mode, the demo database is now always
    saved if it isn't deleted.
  Fixed
  * Improve readability of "Show Tooltips in Thumbnails Window"
    tooltip.
  * Fix image selection order for newly added images
  * Improve date bar behavior when zooming the date bar and
    changing views
  Removed
  * Default shortcut for "View" images was removed.
  * Pressing "Enter" to open the viewer is now the preferred way.
    To restore the old behavior, reassign the shortcut via
    "Settings | Configure Keyboard Shortcuts...".
  Dependencies
  * CMake: 3.18
  * Qt5: 5.15
  * KDE Frameworks: 5.78
- Fix one rpmlint warnings
* Thu Feb 23 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to 5.9.1
  * Hotfix: Due to a problem with the tarme.rb releasme script,
    the 5.9.0 tarball lacked all l10n data.
    We thus had to withdraw the release and tag a new one.
- Changes in 5.9.0
  * Bugfix: Fix crash when forgetting to select images upon import
  * Bugfix: Fix faulty assertion when video thumbnail files cannot
    be written
  * Bugfix: Remove incomplete URL encoding of non-ASCII characters
    in HTML export
  * Bugfix: Fix crash when reimporting deleted files from
    a .kim file
  * Bugfix: Fix multiple issues identified by code analysis tools.
  * Deprecation: Tip of the day feature was removed because it is
    no longer supported by KDE Frameworks.
  * Enhancement: Generic file metadata can now be viewed via the
    Exif metadata dialog.
  * Enhancement: Support other video backends (libVLC, QtAV)
    in addition to Phonon.
  * Enhancement: Add volume controls to video player.
- Update minimum cmake version
- Add BuildRequires QtAV-devel and pkgconfig(libvlc)
* Sun Jun 27 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 5.8.1
  * Enhancement: The "Copy to/Move to" action (triggered by
    pressing F7/F8) can now be run both from the browser and the
    viewer, using the same interface and caching the same last
    target directory
  * Change: Search field no longer gets focus by default (you can
    press '/' to focus)
  * Enhancement: Improve focus switching behavior when using
    Tab/Shift-Tab
  * Enhancement: Add freeform text search to thumbnail view
    (kde#321502)
  * Enhancement: UI improvements for MapView
  * Enhancement: Performance improvement when many thumbnails are
    shown in the MapView
  * Enhancement: Allow relative local URLs in "Open list of files"
    dialog
  * Enhancement: Add option "--vacuum" to kpa-thumbnailtool
  * Bugfix: Fix searching for label (introduced in version 5.4.1)
  * Bugfix: Make splash screen text readable with dark themes
  * Bugfix: Fix crash in context menu of full-screen preview of
    annotation dialog
  * Change: Start maximized on first startup
  * Change: Click behavior for overview page now honors
    system-preference for double- or single-click
- Drop Fix-build-with-Qt-versions-before-5.12.patch, merged
  upstream
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
* Mon Aug 10 2020 wbauer@tmo.at
- Update to 5.7.0
  * Code cleanup:
    + Removed old macros in favor of C++11 features
    + Fixed all deprecation warnings emerged with Qt 5.14
    + Updated old SIGNAL() and SLOT() connects
  * Change: We now no longer depend on libkgeomap and now use
    Marble directly to display geographic information for images
    and maps
  * Change: Store thumbnail size in thumbnail cache. Warning: After
    the thumbnail cache was converted to the new format, older
    versions of KPhotoAlbum can no longer read it!
  * Change: Remove fake password-protection from privacy lock. Even
    with the warning message it might give somebody a false sense
    of security.
  * Change: Don't display HTML export themes missing a name
  * Bugfix: Make sure tag groups are always added to tag list as
    well (kde#423334)
  * Bugfix: Fix crash when changing the toolbar
  * Bugfix: Fix handling of negation in searches (kde#334672)
  * Bugfix: Consistent UI even with dark color schemes
  * Bugfix: Fix behavior of refresh button (introduced in version
    5.5)
  * Bugfix: Fix crash when images are deleted while the viewer
    window is open
  * Bugfix: Always show deletion dialog when closing the viewer and
    images are marked for deletion
  * Bugfix: Fix crash when dragging an image beyond the last
    thumbnail (kde#418251)
  * Bugfix: Fix computation of cell height
  * Bugfix: kpa-merge should not fail if an item of id 0 exists in
    an index file
  * Bugfix: Fix crash when ffmpeg can not extract video thumbnails
    (kde#422555)
  * Bugfix: Removing a token no longer makes it disappear from the
    annotation dialog (kde#423978)
  * Bugfix: Sanitize input for the Tokens category, make Folder and
    Media Type categories read-only (kde#423979)
  * Deprecation: Remove support for KIPI plugins
  * Deprecation: Drop python2 API and associated python scripts
  * Enhancement: Experimental: offer options for image search tuning
  * Enhancement: Smaller improvements to the import dialog
  * Feature: Support for custom color schemes. Note: This feature
    replaces the custom background color for the thumbnail view.
  * Feature: Add new utility kpa-thumbnailtool
- Add Fix-build-with-Qt-versions-before-5.12.patch to make it build
  on Leap 15.1
* Wed Feb 12 2020 wbauer@tmo.at
- Update to 5.6.1
  * Bugfix: Fix crash when associating tags with image areas
    (kde#417360)
- Drop Fix-crash-when-associating-a-tag-with-an-area.patch, merged
  upstream
* Mon Feb 10 2020 wbauer@tmo.at
- Update to 5.6
  * Change: Don't build with remote interface by default.
    The companion app has not been available for Android for a
    while now.
    This feature will either be removed in the future, or the
    Android app will be re-published.
  * Bugfix: Make theme files translatable (kde#406144)
  * Bugfix: Prevent invalid tag id in index.xml when renaming tags
    under some circumstances. When invalid ids already are present
    in an index.xml file, automatically repair if possible, or alert
    the user that manual repair is needed. (kde#415415)
  * Bugfix: Deeply nested tag groups are now displayed correctly in
    the tag groups settings page
  * Enhancement: Huge performance improvements when tagging a large
    number of images
  * Enhancement: Performance improvements for thumbnail view
  * Feature: Support for using purpose plugins
  * Feature: Show newly added tagged areas in the annotation
    dialog's fullscreen preview
  * Feature: Add filter to thumbnail view, allowing filtering by
    token or rating
  * Feature: Make it possible to hide the search bar and the filter
    toolbar
- Add Fix-crash-when-associating-a-tag-with-an-area.patch to fix a
  crash when associating tags with image areas (kde#417360)
* Mon Apr 29 2019 wbauer@tmo.at
- Update to 5.5
  * Bugfix: Fix compilation with exiv2 0.27
  * Enhancement: Display dates when browsing categories. When
    browsing categories, two columns "Start Date" and "End Date"
    have been added. These columns correspond to the time range of
    the images tagged with that particular tag.
  * Enhancement: Faster display of browser overview page. Depending
    on the current context, the overview should now be displayed
    significantly faster (on my particular system the time to
    display the "Home" page dropped from 500ms to 25ms).
  * Change: More intuitive handling of down button in annotation
    dialog. Pressing the "down" button in a ListSelect in the
    annotation dialog now selects the first item, not the second
    one.
  * Change: Use non-linear scaling for DateBar by default
    (kde#356810)
  * Change: Instead of having "increase/decrease thumbnail storage
    size buttons", show a "Thumbnail settings" button in the status
    bar (kde#357239)
  * Bugfix: Restore correct behaviour for "Statistics..." action
  * Bugfix: Fix loading of user shortcuts for the annotation dialog
  * Enhancement: Add "clear selection" menu item
  * Change: More detailed debug output
  * Deprecation: Removed compatibility with Qt versions < 5.9
  * Deprecation: Removed support for MPlayer. For video thumbails,
    only ffmpeg is supported.
  * Enhancement: Smaller performance improvements during startup
  * Bugfix: Fix zooming for raw images
- Drop patches merged upstream:
  * Use-Exiv2-0.27-if-available.patch
  * Fix-compilation-with-exiv2-0.27.patch
- Drop 0001-Fix-build-with-Qt-5.7-and-lower.patch, it requires Qt
  5.9 and KF 5.44 now, the versions in Leap 42.3 are just too old
- Use %%kf5_find_htmldocs macro to generate the translated docs
  filelist
* Wed Feb  6 2019 wbauer@tmo.at
- Update to 5.4.2
  * Prevent loss of tagging data when upgrading from v5.3 or older
    (kde#403668)
  * Fix crash when right-clicking in thumbnail view (kde#403721)
* Thu Jan  3 2019 wbauer@tmo.at
- Add upstream patches to fix build with exiv2-0.27:
  * Use-Exiv2-0.27-if-available.patch
  * Fix-compilation-with-exiv2-0.27.patch
* Sat Oct 13 2018 wbauer@tmo.at
- Update to 5.4
  * Change: Database file now uses version 8 format.
  * Update/Bugfix: Various l10n fixes concerning capitalization and
    contexts.
  * Update: Review default values for Settings, pre-define
    contemporary ones:
  - Ignore common auto-generated Exif comments by default.
  - The database file is now optimized for speed by default
    (old default value: optimized for human readability)
  - If less than 20 images are matched, the thumbnail view is
    shown (old default value: 0)
  - The thumbnail grid is now optimized for a 3:2 aspect ratio
    (old default value: 4:3)
  - The size of thumbnails is now 256x256 pixels
    (old default value: 150)
  - When starting a slideshow, it is now shown in fullscreen by
    default (old default value: 800x600px)
  - Detect edited images by default
    (old default value: feature was not configured)
    This means that images that have been edited using the
    "create a copy and open" feature now are recognized by
    default. The tags of the original image are copied and both
    images are automatically stacked.
  * Bugfix: Use the correct initial value when renaming tag groups
    using the settings page.
  * Enhancement: Improve startup 10-15%% by eliding unnecessary
    category creation.
  * Bugfixes: Don't continue accessing the Exif db if unusable,
    reset failed state when recreating db.
  * Bugfix: Fix display of "<=" and ">=" rating options in search
    dialog.
  * Bugfix: Fix overflow in parsing GPS information from Exif,
    leading to false coordinates.
  * Enhancement: Add FreeBSD as supported platform
  * Bugfix: Fixed build with Qt 5.11, replace deprecated API usage.
  * Enhancement: Do not write unnecessary data to index.xml by
    using defaults.
  * Enhancements: Improved thumbnail generation:
  - Improve thumbnail generation speed and efficiency.
  - Overlap thumbnail create with image load.
  - Generate new thumbnails for moved images detected during load.
  * Bugfix: More reliable auto-stacking of images.
  * Enhancements: Improved speed of loading/removing new images:
  - Insert Exif data for each loaded image as it's loaded, but
    within a transaction.
  - Elide unnecessary MD5 computations.
  - Reduce I/O wait time of image loader by introducing a scout
    thread.
  - Improve I/O efficiency for MD5 calculation.
  - Fetch Exif data only once during load.
  - Improve efficiency of loading previews from RAW images.
  - Ignore more sidecar files to improve performance
    (.xmp, .pp3, and .pto).
  * Enhancement/Bugfix: Scale the date bar appropriately upon
    exposure, add one minute scaler.
  * Update: Make Android app compilable with C++14 and later.
  * Rework: General code cleanup, coding standard updates etc. all
    over the place.
- Drop Fix-build-with-Qt-511.patch, merged upstream
- Add 0001-Fix-build-with-Qt-5.7-and-lower.patch to make it build
  on Leap 42.3
* Mon Jun  4 2018 christophe@krop.fr
- Add Fix-build-with-Qt-511.patch
- Run spec-cleaner
* Tue Jan 23 2018 wbauer@tmo.at
- Update to 5.3
  * Removal of the face management, libkface is unmaintained.
  * Bugfix: Fix crash with prepared SQL queries on Qt 5.10.
  * Enhancement: Speed up startup by not counting images several
    times.
  * Enhancement: Improve robustness of video length detection and
    thumbnail extraction.
  * Enhancement: Made the full screen image preview in the
    annotation dialog reachable by a button.
  * Change: Display absolute numbers instead of percentage when
    loading new images.
  * Bugfix (kde#385551): Remove dead/unreachable code.
  * Enhancement: Speed up video thumbnail creation.
  * New: Added the "kpa-merge" script (by Robert Krawitz), which
    can merge two (version 7) databases and also remove unused
    labels.
  * Enhancement: Speed up removal of images from database.
  * Enhancement: Add a "Maximum megapixels" option to the search
    dialog.
  * Enhancement: Don't re-compute an MD5 sum we already have when
    adding new images.
  * Bugfix: Overall KF5 port regression fixes (missing buttons
    etc.).
  * Bugfix: Sometimes, areas weren't updated correctly when
    annotating images and changing between them.
- Update build requirements
* Tue Feb 28 2017 wbauer@tmo.at
- Update to 5.2
  * Enhancement: Add the "Geo Position" selection page to the
    browser (Thanks to Matthias Füssel for the original patch!)
  * Bugfix: Fixed disabled items in browser overview page.
  * Bugfix (kde#376635): Fix renaming and deletion of memberMap
    members.
  * Change: Maintained compatibility with Qt < 5.6 (for now).
  * Bugfix: Fixed compilation with -fno-operator-names.
  * Bugfix: Added .kim import test case and fixed the import when
    using external images.
  * Enhancement: Improved the default layout for annotation dialog.
  * Bugfix (kde#374431): Prevent invalid characters in image
    description.
  * Bugfix: Fixed the path of kphotoalbumui.rc in kpa-backup.sh
  * Bugfix: Reviewed and fixed the install directories.
  * Bugfix: Fixed the date view on the birthdays page.
  * Bugfix: Fixed some issues in the thumbnail build progress
    counter.
  * Bugfix: Don't show empty descriptions in the InfoBox.
  * Bugfix: Fixed the search dialog.
  * Bugfix: Fixed the "remove tokens" dialog.
- Drop Maintain-compatibility-with-Qt-5.5.patch and
  fix-build-with-ecm-5.31.patch, included in this release
* Sun Feb 19 2017 wbauer@tmo.at
- Update to 5.1
  * Enhancement (kde#370373): Made writing index.xml deterministic,
    so that diffing it produces minimal changes.
  * Bugfix: Fixed areas not drawn when a photo was viewed after a
    video in the Annotation Dialog.
  * Bugfix (kde#373263): KPA crashed when editing a birth date.
    Also restored the functionality if the whole birth date dialog,
    which was broken due to the KF5/Qt5 port.
  * Bugfix (kde#373128): Fixed the "Copy image(s) to..." and
    "Link image(s) to..." menu.
  * Bugfix: Prevent duplicate positionable tags. All except one are
    lost when saving. Apparently, nobody noticed this flaw since
    the introduction of positionable tags ;-)
  * Bugfix: Prevent the image preview from flickering in the
    Annotation Dialog.
  * Bugfix: Fixed various issues with the Android Remote Control.
- Drop fix-build-with-qt5.6.1.patch and fix-build-with-qt5.5.patch,
  included in this release
- Add fix-build-with-ecm-5.31.patch to fix build with KF 5.31.0
- Add Maintain-compatibility-with-Qt-5.5.patch to make it build
  with Qt 5.5 in Leap 42.1
- Define ENABLE_PLAYGROUND to keep the face detection and
  recognition features which are now disabled by default
* Thu Nov 10 2016 wbauer@tmo.at
- Add missing libexiv2-devel build requirement
* Mon Nov  7 2016 wbauer@tmo.at
- Add fix-build-with-qt5.6.1.patch and fix-build-with-qt5.5.patch
  to fix the build for Leap 42.1
* Fri Oct 28 2016 hrvoje.senjan@gmail.com
- Update to 5.0.1
  * Ported KPA to Qt 5 and KF5, including updating all
    depreceated code. We also do not depend on the KDE4LibsSupport
    compatibility class.
  * Cleaned up includes and stray references, dropped some
    legacy compatibility code.
  * Updated the (many/most of the) icons to get a uniform "KF5 look".
  * Revised commandline options.
  * Use ffmpeg/ffprobe for video if available.
  * Usability improvements for HTML export.
  * We now ship AppData.
  * Fixed some leaks detected by Valgrind and warnings by
    the clang static analyzer.
* Mon Aug  1 2016 wbauer@tmo.at
- Update to 4.7.2
  * Bugfix: Annotation dialog: Fix up/down key if there's a single
    match for an entered string.
  * Enhancement: Tag names are now matched word by word against all
    parts of the search string (using the Search dialog).
  * Bugfix: Prevent duplication of special categories when updating
    to dbv7.
  * Bugfix: Don't exclude "Z" when filling the "Tokens" category
    for the first time.
  * Bugfix: Overall fixes of assertions.
  * Change: Dropped compatibility with libkipi < 2.0.
* Mon May  2 2016 wbauer@tmo.at
- Update to 4.7.1
  * too many changes to list here, please see
    https://www.kphotoalbum.org/ or the included ChangeLog file
- Add libkface-devel to the BuildRequires to enable the new face
  detection and recognition features
- adjust file list
* Sun Dec  8 2013 cgiboudeaux@gmx.com
- Update to 4.4
  * Support for kipi 2.0.0
  * Greatly improved database save performance
  * Merging duplicate images (based on md5sum) is now possible
  * BUGFIX: Tooltips did not update when scrolling using the wheel
  * BUGFIX: Tooltip did not work on videos
* Sun Feb 10 2013 ctrippe@opensuse.org
- Update to version 4.3
  New features concentrate on video support improvements and background
  tasks. Also the database backend has been dropped completely leaving
  the XML backend as the only option. Automatic stacking of images
  based on file version detection has been brought to the maintenance
  menu giving control to the user instead of only performing the
  action upon starting of KPhotoAlbum.
- dropped patch kphotoalbum-4.2-docbook_xml.diff
- added the following patches
  * 0003-KIPI-Use-the-generic-way-of-passing-date-time-argume.patch
  * fix_open_raw_desktop.diff
  * kphotoalbum-4.3-libkdcraw.patch
  * kphotoalbum-libkipi2.patch
* Tue Jul  3 2012 toddrme2178@gmail.com
- Update to version 4.2
  * Rewrite of ThumbnailView with speed improvements, pre-loading
    and background thumbnail generation.
  * ToolTip on ThumbnailView is activated only if mouse is not
    moving.
  * Updated documentation.
  * Copy-paste of tags from one image to the next one.
  * RAW workflow improvements on speed and functionality. Use
    embedded thumbnail if available in decent size, open the RAW
    file in RAW editor instead of the developed JPEG, search for
    only RAW files.
  * Rating images with number keys 0-5.
  * Annotation dialog and search improvements.
  * HTML export improvements.
  * Option to skip symbolic links when detecting new files.
  * Multi core CPU improvements.
  * Plenty of crashes fixed.
  * Usability improvements.
* Fri Jul 30 2010 tittiatcoke@gmail.com
- Update to version 4.1.1
* Sat Aug  1 2009 tittiatcoke@gmail.com
- Update to version 4.0.2
* Tue Jul 21 2009 tittiatcoke@gmail.com
- Update to version 4.0.1
* Mon May 11 2009 jcnengel@googlemail.com
- Initial checkin version 4.0
